@@ -42,8 +42,7 @@ class TestCommandLineInterface(unittest.TestCase):
 
         try:
             remove('./data/sample.1.ar.cp1256.srt')
-        except IOError as e:
-            print(str(e))
+        except:
             pass
 
     def test_single_verbose_file(self):
